@@ -18,10 +18,13 @@ sub standard_keys_and_values : Test(startup) {
     my ($self) = @_;
 
     my ( $keys_ref, $values_ref ) = $self->set_standard_keys_and_values();
-    $self->{keys}      = $keys_ref;
-    $self->{values}    = $values_ref;
-    $self->{keynames}  = [ keys( %{$keys_ref} ) ];
-    $self->{key_count} = scalar( @{ $self->{keynames} } );
+    $self->{keys}          = $keys_ref;
+    $self->{values}        = $values_ref;
+    $self->{keynames}      = [ keys( %{$keys_ref} ) ];
+    $self->{key_count}     = scalar( @{ $self->{keynames} } );
+    $self->{all_test_keys} = [ values(%$keys_ref), $self->extra_test_keys() ];
+    $self->{all_test_keys_hash} =
+      { map { ( $_, 1 ) } @{ $self->{all_test_keys} } };
 }
 
 sub kvpair {
@@ -118,6 +121,20 @@ sub set_standard_keys_and_values {
     return ( \%keys, \%values );
 }
 
+# Extra keys (beyond the standard keys above) that we may use in these
+# tests. We need to adhere to this for the benefit of drivers that don't
+# support get_keys (like memcached) - they simulate get_keys(), clear(),
+# etc. by using this fixed list of keys.
+#
+sub extra_test_keys {
+    my ($class) = @_;
+    return (
+        '', '2', 'medium2', 'foo',
+        ( map { "done$_" } ( 0 .. 2 ) ),
+        ( map { "key$_" }  ( 0 .. 20 ) )
+    );
+}
+
 sub set_some_keys {
     my ( $self, $c ) = @_;
 
@@ -318,10 +335,11 @@ sub test_expires_defaults : Test(4) {
     my $cache;
 
     my $set_and_confirm_expires_at = sub {
-        my ( $expected_expires_at, $desc ) = @_;
-        my ( $key, $value ) = ( random_string(10), random_string(10) );
+        my ( $expected_expires_at, $desc )  = @_;
+        my ( $key,                 $value ) = $self->kvpair();
         $cache->set( $key, $value );
         is( $cache->get_expires_at($key), $expected_expires_at, $desc );
+        $cache->clear();
     };
 
     $cache = $self->new_cache( expires_in => 10 );
@@ -1182,13 +1200,12 @@ sub test_discard_timeout : Test(4) {
     );
     ok( defined( $cache->discard_timeout ) && $cache->discard_timeout > 1,
         "positive discard timeout" );
-    $cache->discard_timeout(2);
-    is( $cache->discard_timeout, 2, "can set timeout" );
+    $cache->discard_timeout(1);
+    is( $cache->discard_timeout, 1, "can set timeout" );
     my $start_time = time;
     $cache->set( 2, 2 );
     throws_ok { $cache->discard_to_size(0) } qr/discard timeout .* reached/;
-    ok( time > $start_time && time < $start_time + 5,
-        "timed out in 2 seconds" );
+    ok( time > $start_time && time < $start_time + 3, "timed out in 1 second" );
 }
 
 sub test_size_awareness_with_subcaches : Test(19) {
